# Copyright 2023 The KerasCV Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""MobileNetV3 model preset configurations."""

backbone_presets_no_weights = {
    "mobilenet_v3_small": {
        "metadata": {
            "description": (
                "MobileNetV3 model with 14 layers where the batch "
                "normalization and hard-swish activation are applied after the "
                "convolution layers."
            ),
            "params": 933502,
            "official_name": "MobileNetV3",
            "path": "mobilenetv3",
        },
        "class_name": "keras_cv>MobileNetV3Backbone",
        "config": {
            "stackwise_expansion": [
                1,
                72.0 / 16,
                88.0 / 24,
                4,
                6,
                6,
                3,
                3,
                6,
                6,
                6,
            ],
            "stackwise_filters": [16, 24, 24, 40, 40, 40, 48, 48, 96, 96, 96],
            "stackwise_kernel_size": [3, 3, 3, 5, 5, 5, 5, 5, 5, 5, 5],
            "stackwise_stride": [2, 2, 1, 2, 1, 1, 1, 1, 2, 1, 1],
            "stackwise_se_ratio": [
                0.25,
                None,
                None,
                0.25,
                0.25,
                0.25,
                0.25,
                0.25,
                0.25,
                0.25,
                0.25,
            ],
            "stackwise_activation": [
                "relu",
                "relu",
                "relu",
                "hard_swish",
                "hard_swish",
                "hard_swish",
                "hard_swish",
                "hard_swish",
                "hard_swish",
                "hard_swish",
                "hard_swish",
            ],
            "include_rescaling": True,
            "input_shape": (None, None, 3),
            "input_tensor": None,
            "alpha": 1.0,
        },
    },
    "mobilenet_v3_large": {
        "metadata": {
            "description": (
                "MobileNetV3 model with 28 layers where the batch "
                "normalization and hard-swish activation are applied after the "
                "convolution layers."
            ),
            "params": 2994518,
            "official_name": "MobileNetV3",
            "path": "mobilenetv3",
        },
        "class_name": "keras_cv>MobileNetV3Backbone",
        "config": {
            "stackwise_expansion": [
                1,
                4,
                3,
                3,
                3,
                3,
                6,
                2.5,
                2.3,
                2.3,
                6,
                6,
                6,
                6,
                6,
            ],
            "stackwise_filters": [
                16,
                24,
                24,
                40,
                40,
                40,
                80,
                80,
                80,
                80,
                112,
                112,
                160,
                160,
                160,
            ],
            "stackwise_kernel_size": [
                3,
                3,
                3,
                5,
                5,
                5,
                3,
                3,
                3,
                3,
                3,
                3,
                5,
                5,
                5,
            ],
            "stackwise_stride": [1, 2, 1, 2, 1, 1, 2, 1, 1, 1, 1, 1, 2, 1, 1],
            "stackwise_se_ratio": [
                None,
                None,
                None,
                0.25,
                0.25,
                0.25,
                None,
                None,
                None,
                None,
                0.25,
                0.25,
                0.25,
                0.25,
                0.25,
            ],
            "stackwise_activation": [
                "relu",
                "relu",
                "relu",
                "relu",
                "relu",
                "relu",
                "hard_swish",
                "hard_swish",
                "hard_swish",
                "hard_swish",
                "hard_swish",
                "hard_swish",
                "hard_swish",
                "hard_swish",
                "hard_swish",
            ],
            "include_rescaling": True,
            "input_shape": (None, None, 3),
            "input_tensor": None,
            "alpha": 1.0,
        },
    },
}

backbone_presets_with_weights = {
    "mobilenet_v3_large_imagenet": {
        "metadata": {
            "description": (
                "MobileNetV3 model with 28 layers where the batch "
                "normalization and hard-swish activation are applied after the "
                "convolution layers. "
                "Pre-trained on the ImageNet 2012 classification task."
            ),
            "params": 2994518,
            "official_name": "MobileNetV3",
            "path": "mobilenetv3",
        },
        "class_name": "keras_cv>MobileNetV3Backbone",
        "config": backbone_presets_no_weights["mobilenet_v3_large"]["config"],
        "weights_url": "https://storage.googleapis.com/keras-cv/models/mobilenetv3/mobilenetv3_large_imagenet_backbone.h5",  # noqa: E501
        "weights_hash": "ec55ea2f4f4ee9a2ddf3ee8e2dd784e9d5732690c1fc5afc7e1b2a66703f3337",  # noqa: E501
    },
    "mobilenet_v3_small_imagenet": {
        "metadata": {
            "description": (
                "MobileNetV3 model with 14 layers where the batch "
                "normalization and hard-swish activation are applied after the "
                "convolution layers. "
                "Pre-trained on the ImageNet 2012 classification task."
            ),
            "params": 933502,
            "official_name": "MobileNetV3",
            "path": "mobilenetv3",
        },
        "class_name": "keras_cv>MobileNetV3Backbone",
        "config": backbone_presets_no_weights["mobilenet_v3_small"]["config"],
        "weights_url": "https://storage.googleapis.com/keras-cv/models/mobilenetv3/mobilenetv3_small_imagenet_backbone.h5",  # noqa: E501
        "weights_hash": "592c2707edfc6c673a3b2d9aaf76dee678557f4a32d573c74f96c8122effa503",  # noqa: E501
    },
}

backbone_presets = {
    **backbone_presets_no_weights,
    **backbone_presets_with_weights,
}




# Copyright 2023 The KerasCV Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""MiT model preset configurations."""

backbone_presets_no_weights = {
    "mit_b0": {
        "metadata": {
            "description": (
                "MiT (MixTransformer) model with 8 transformer blocks."
            ),
            "params": 3321962,
            "official_name": "MiT",
            "path": "mit",
        },
        "class_name": "keras_cv>MiTBackbone",
        "config": {
            "embedding_dims": [32, 64, 160, 256],
            "depths": [2, 2, 2, 2],
            "include_rescaling": True,
            "input_shape": (224, 224, 3),
            "input_tensor": None,
        },
    },
    "mit_b1": {
        "metadata": {
            "description": (
                "MiT (MixTransformer) model with 8 transformer blocks."
            ),
            "params": 13156554,
            "official_name": "MiT",
            "path": "mit",
        },
        "class_name": "keras_cv>MiTBackbone",
        "config": {
            "embedding_dims": [64, 128, 320, 512],
            "depths": [2, 2, 2, 2],
            "include_rescaling": True,
            "input_shape": (224, 224, 3),
            "input_tensor": None,
        },
    },
    "mit_b2": {
        "metadata": {
            "description": (
                "MiT (MixTransformer) model with 16 transformer blocks."
            ),
            "params": 24201418,
            "official_name": "MiT",
            "path": "mit",
        },
        "class_name": "keras_cv>MiTBackbone",
        "config": {
            "embedding_dims": [64, 128, 320, 512],
            "depths": [3, 4, 6, 3],
            "include_rescaling": True,
            "input_shape": (224, 224, 3),
            "input_tensor": None,
        },
    },
    "mit_b3": {
        "metadata": {
            "description": (
                "MiT (MixTransformer) model with 28 transformer blocks."
            ),
            "params": 44077258,
            "official_name": "MiT",
            "path": "mit",
        },
        "class_name": "keras_cv>MiTBackbone",
        "config": {
            "embedding_dims": [64, 128, 320, 512],
            "depths": [3, 4, 18, 3],
            "include_rescaling": True,
            "input_shape": (224, 224, 3),
            "input_tensor": None,
        },
    },
    "mit_b4": {
        "metadata": {
            "description": (
                "MiT (MixTransformer) model with 41 transformer blocks."
            ),
            "params": 60847818,
            "official_name": "MiT",
            "path": "mit",
        },
        "class_name": "keras_cv>MiTBackbone",
        "config": {
            "embedding_dims": [64, 128, 320, 512],
            "depths": [3, 8, 27, 3],
            "include_rescaling": True,
            "input_shape": (224, 224, 3),
            "input_tensor": None,
        },
    },
    "mit_b5": {
        "metadata": {
            "description": (
                "MiT (MixTransformer) model with 52 transformer blocks."
            ),
            "params": 81448138,
            "official_name": "MiT",
            "path": "mit",
        },
        "class_name": "keras_cv>MiTBackbone",
        "config": {
            "embedding_dims": [64, 128, 320, 512],
            "depths": [3, 6, 40, 3],
            "include_rescaling": True,
            "input_shape": (224, 224, 3),
            "input_tensor": None,
        },
    },
}

backbone_presets_with_weights = {
    "mit_b0_imagenet": {
        "metadata": {
            "description": (
                "MiT (MixTransformer) model with 8 transformer blocks. Pre-trained on ImageNet-1K and scores 69% top-1 accuracy on the validation set."  # noqa: E501
            ),
            "params": 3321962,
            "official_name": "MiT",
            "path": "mit",
        },
        "class_name": "keras_cv>MiTBackbone",
        "config": {
            "embedding_dims": [32, 64, 160, 256],
            "depths": [2, 2, 2, 2],
            "include_rescaling": True,
            "input_shape": (224, 224, 3),
            "input_tensor": None,
        },
        "weights_url": "https://storage.googleapis.com/keras-cv/models/mitb0/imagenet/classification-v0.h5",  # noqa: E501
        "weights_hash": "8e0c416cd330b6fa0bcfb3a5ccc43edcbcabf6a463aee3c2a9b6a1398c207d10",  # noqa: E501
    },
}

backbone_presets = {
    **backbone_presets_no_weights,
    **backbone_presets_with_weights,
}




# Copyright 2023 The KerasCV Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""EfficientNetV2 model preset configurations."""

backbone_presets_no_weights = {
    "efficientnetv2_s": {
        "metadata": {
            "description": (
                "EfficientNet architecture with 6 convolutional blocks."
            ),
            "params": 20331360,
            "official_name": "EfficientNetV2",
            "path": "efficientnetv2",
        },
        "class_name": "keras_cv>EfficientNetV2Backbone",
        "config": {
            "width_coefficient": 1.0,
            "depth_coefficient": 1.0,
            "skip_connection_dropout": 0.2,
            "depth_divisor": 8,
            "min_depth": 8,
            "activation": "swish",
            "include_rescaling": True,
            "input_shape": (None, None, 3),
            "input_tensor": None,
            "stackwise_kernel_sizes": [3, 3, 3, 3, 3, 3],
            "stackwise_num_repeats": [2, 4, 4, 6, 9, 15],
            "stackwise_input_filters": [24, 24, 48, 64, 128, 160],
            "stackwise_output_filters": [24, 48, 64, 128, 160, 256],
            "stackwise_expansion_ratios": [1, 4, 4, 4, 6, 6],
            "stackwise_squeeze_and_excite_ratios": [
                0.0,
                0.0,
                0,
                0.25,
                0.25,
                0.25,
            ],
            "stackwise_strides": [1, 2, 2, 2, 1, 2],
            "stackwise_conv_types": [
                "fused",
                "fused",
                "fused",
                "unfused",
                "unfused",
                "unfused",
            ],
        },
    },
    "efficientnetv2_m": {
        "metadata": {
            "description": (
                "EfficientNet architecture with 7 convolutional blocks."
            ),
            "params": 53150388,
            "official_name": "EfficientNetV2",
            "path": "efficientnetv2",
        },
        "class_name": "keras_cv>EfficientNetV2Backbone",
        "config": {
            "width_coefficient": 1.0,
            "depth_coefficient": 1.0,
            "skip_connection_dropout": 0.2,
            "depth_divisor": 8,
            "min_depth": 8,
            "activation": "swish",
            "include_rescaling": True,
            "input_shape": (None, None, 3),
            "input_tensor": None,
            "stackwise_kernel_sizes": [3, 3, 3, 3, 3, 3, 3],
            "stackwise_num_repeats": [3, 5, 5, 7, 14, 18, 5],
            "stackwise_input_filters": [24, 24, 48, 80, 160, 176, 304],
            "stackwise_output_filters": [24, 48, 80, 160, 176, 304, 512],
            "stackwise_expansion_ratios": [1, 4, 4, 4, 6, 6, 6],
            "stackwise_squeeze_and_excite_ratios": [
                0,
                0,
                0,
                0.25,
                0.25,
                0.25,
                0.25,
            ],
            "stackwise_strides": [1, 2, 2, 2, 1, 2, 1],
            "stackwise_conv_types": [
                "fused",
                "fused",
                "fused",
                "unfused",
                "unfused",
                "unfused",
                "unfused",
            ],
        },
    },
    "efficientnetv2_l": {
        "metadata": {
            "description": (
                "EfficientNet architecture with 7 convolutional "
                "blocks, but more filters the in `efficientnetv2_m`."
            ),
            "params": 117746848,
            "official_name": "EfficientNetV2",
            "path": "efficientnetv2",
        },
        "class_name": "keras_cv>EfficientNetV2Backbone",
        "config": {
            "width_coefficient": 1.0,
            "depth_coefficient": 1.0,
            "skip_connection_dropout": 0.2,
            "depth_divisor": 8,
            "min_depth": 8,
            "activation": "swish",
            "include_rescaling": True,
            "input_shape": (None, None, 3),
            "input_tensor": None,
            "stackwise_kernel_sizes": [3, 3, 3, 3, 3, 3, 3],
            "stackwise_num_repeats": [4, 7, 7, 10, 19, 25, 7],
            "stackwise_input_filters": [32, 32, 64, 96, 192, 224, 384],
            "stackwise_output_filters": [32, 64, 96, 192, 224, 384, 640],
            "stackwise_expansion_ratios": [1, 4, 4, 4, 6, 6, 6],
            "stackwise_squeeze_and_excite_ratios": [
                0,
                0,
                0,
                0.25,
                0.25,
                0.25,
                0.25,
            ],
            "stackwise_strides": [1, 2, 2, 2, 1, 2, 1],
            "stackwise_conv_types": [
                "fused",
                "fused",
                "fused",
                "unfused",
                "unfused",
                "unfused",
                "unfused",
            ],
        },
    },
    "efficientnetv2_b0": {
        "metadata": {
            "description": (
                "EfficientNet B-style architecture with 6 "
                "convolutional blocks. This B-style model has "
                "`width_coefficient=1.0` and `depth_coefficient=1.0`."
            ),
            "params": 5919312,
            "official_name": "EfficientNetV2",
            "path": "efficientnetv2",
        },
        "class_name": "keras_cv>EfficientNetV2Backbone",
        "config": {
            "width_coefficient": 1.0,
            "depth_coefficient": 1.0,
            "skip_connection_dropout": 0.2,
            "depth_divisor": 8,
            "min_depth": 8,
            "activation": "swish",
            "include_rescaling": True,
            "input_shape": (None, None, 3),
            "input_tensor": None,
            "stackwise_kernel_sizes": [3, 3, 3, 3, 3, 3],
            "stackwise_num_repeats": [1, 2, 2, 3, 5, 8],
            "stackwise_input_filters": [32, 16, 32, 48, 96, 112],
            "stackwise_output_filters": [16, 32, 48, 96, 112, 192],
            "stackwise_expansion_ratios": [1, 4, 4, 4, 6, 6],
            "stackwise_squeeze_and_excite_ratios": [0, 0, 0, 0.25, 0.25, 0.25],
            "stackwise_strides": [1, 2, 2, 2, 1, 2],
            "stackwise_conv_types": [
                "fused",
                "fused",
                "fused",
                "unfused",
                "unfused",
                "unfused",
            ],
        },
    },
    "efficientnetv2_b1": {
        "metadata": {
            "description": (
                "EfficientNet B-style architecture with 6 "
                "convolutional blocks. This B-style model has "
                "`width_coefficient=1.0` and `depth_coefficient=1.1`."
            ),
            "params": 6931124,
            "official_name": "EfficientNetV2",
            "path": "efficientnetv2",
        },
        "class_name": "keras_cv>EfficientNetV2Backbone",
        "config": {
            "width_coefficient": 1.0,
            "depth_coefficient": 1.1,
            "skip_connection_dropout": 0.2,
            "depth_divisor": 8,
            "min_depth": 8,
            "activation": "swish",
            "include_rescaling": True,
            "input_shape": (None, None, 3),
            "input_tensor": None,
            "stackwise_kernel_sizes": [3, 3, 3, 3, 3, 3],
            "stackwise_num_repeats": [1, 2, 2, 3, 5, 8],
            "stackwise_input_filters": [32, 16, 32, 48, 96, 112],
            "stackwise_output_filters": [16, 32, 48, 96, 112, 192],
            "stackwise_expansion_ratios": [1, 4, 4, 4, 6, 6],
            "stackwise_squeeze_and_excite_ratios": [0, 0, 0, 0.25, 0.25, 0.25],
            "stackwise_strides": [1, 2, 2, 2, 1, 2],
            "stackwise_conv_types": [
                "fused",
                "fused",
                "fused",
                "unfused",
                "unfused",
                "unfused",
            ],
        },
    },
    "efficientnetv2_b2": {
        "metadata": {
            "description": (
                "EfficientNet B-style architecture with 6 "
                "convolutional blocks. This B-style model has "
                "`width_coefficient=1.1` and `depth_coefficient=1.2`."
            ),
            "params": 8769374,
            "official_name": "EfficientNetV2",
            "path": "efficientnetv2",
        },
        "class_name": "keras_cv>EfficientNetV2Backbone",
        "config": {
            "width_coefficient": 1.1,
            "depth_coefficient": 1.2,
            "skip_connection_dropout": 0.2,
            "depth_divisor": 8,
            "min_depth": 8,
            "activation": "swish",
            "include_rescaling": True,
            "input_shape": (None, None, 3),
            "input_tensor": None,
            "stackwise_kernel_sizes": [3, 3, 3, 3, 3, 3],
            "stackwise_num_repeats": [1, 2, 2, 3, 5, 8],
            "stackwise_input_filters": [32, 16, 32, 48, 96, 112],
            "stackwise_output_filters": [16, 32, 48, 96, 112, 192],
            "stackwise_expansion_ratios": [1, 4, 4, 4, 6, 6],
            "stackwise_squeeze_and_excite_ratios": [0, 0, 0, 0.25, 0.25, 0.25],
            "stackwise_strides": [1, 2, 2, 2, 1, 2],
            "stackwise_conv_types": [
                "fused",
                "fused",
                "fused",
                "unfused",
                "unfused",
                "unfused",
            ],
        },
    },
    "efficientnetv2_b3": {
        "metadata": {
            "description": (
                "EfficientNet B-style architecture with 7 "
                "convolutional blocks. This B-style model has "
                "`width_coefficient=1.2` and `depth_coefficient=1.4`."
            ),
            "params": 12930622,
            "official_name": "EfficientNetV2",
            "path": "efficientnetv2",
        },
        "class_name": "keras_cv>EfficientNetV2Backbone",
        "config": {
            "width_coefficient": 1.2,
            "depth_coefficient": 1.4,
            "skip_connection_dropout": 0.2,
            "depth_divisor": 8,
            "min_depth": 8,
            "activation": "swish",
            "include_rescaling": True,
            "input_shape": (None, None, 3),
            "input_tensor": None,
            "stackwise_kernel_sizes": [3, 3, 3, 3, 3, 3],
            "stackwise_num_repeats": [1, 2, 2, 3, 5, 8],
            "stackwise_input_filters": [32, 16, 32, 48, 96, 112],
            "stackwise_output_filters": [16, 32, 48, 96, 112, 192],
            "stackwise_expansion_ratios": [1, 4, 4, 4, 6, 6],
            "stackwise_squeeze_and_excite_ratios": [0, 0, 0, 0.25, 0.25, 0.25],
            "stackwise_strides": [1, 2, 2, 2, 1, 2],
            "stackwise_conv_types": [
                "fused",
                "fused",
                "fused",
                "unfused",
                "unfused",
                "unfused",
            ],
        },
    },
}

backbone_presets_with_weights = {
    "efficientnetv2_s_imagenet": {
        "metadata": {
            "description": (
                "EfficientNet architecture with 6 convolutional "
                "blocks. Weights are initialized to pretrained imagenet "
                "classification weights.Published weights are capable of "
                "scoring 83.9%top 1 accuracy "
                "and 96.7% top 5 accuracy on imagenet."
            ),
            "params": 20331360,
            "official_name": "EfficientNetV2",
            "path": "efficientnetv2",
        },
        "class_name": "keras_cv>EfficientNetV2Backbone",
        "config": {
            "width_coefficient": 1.0,
            "depth_coefficient": 1.0,
            "skip_connection_dropout": 0.2,
            "depth_divisor": 8,
            "min_depth": 8,
            "activation": "swish",
            "include_rescaling": True,
            "input_shape": (None, None, 3),
            "input_tensor": None,
            "stackwise_kernel_sizes": [3, 3, 3, 3, 3, 3],
            "stackwise_num_repeats": [2, 4, 4, 6, 9, 15],
            "stackwise_input_filters": [24, 24, 48, 64, 128, 160],
            "stackwise_output_filters": [24, 48, 64, 128, 160, 256],
            "stackwise_expansion_ratios": [1, 4, 4, 4, 6, 6],
            "stackwise_squeeze_and_excite_ratios": [
                0.0,
                0.0,
                0,
                0.25,
                0.25,
                0.25,
            ],
            "stackwise_strides": [1, 2, 2, 2, 1, 2],
            "stackwise_conv_types": [
                "fused",
                "fused",
                "fused",
                "unfused",
                "unfused",
                "unfused",
            ],
        },
        "weights_url": "https://storage.googleapis.com/keras-cv/models/efficientnetv2s/imagenet/classification-v0-notop.h5",  # noqa: E501
        "weights_hash": "80555436ea49100893552614b4dce98de461fa3b6c14f8132673817d28c83654",  # noqa: E501
    },
    "efficientnetv2_b0_imagenet": {
        "metadata": {
            "description": (
                "EfficientNet B-style architecture with 6 "
                "convolutional blocks. This B-style model has "
                "`width_coefficient=1.0` and `depth_coefficient=1.0`. "
                "Weights are "
                "initialized to pretrained imagenet classification weights. "
                "Published weights are capable of scoring 77.1%	top 1 accuracy "
                "and 93.3% top 5 accuracy on imagenet."
            ),
            "params": 5919312,
            "official_name": "EfficientNetV2",
            "path": "efficientnetv2",
        },
        "class_name": "keras_cv>EfficientNetV2Backbone",
        "config": {
            "width_coefficient": 1.0,
            "depth_coefficient": 1.0,
            "skip_connection_dropout": 0.2,
            "depth_divisor": 8,
            "min_depth": 8,
            "activation": "swish",
            "include_rescaling": True,
            "input_shape": (None, None, 3),
            "input_tensor": None,
            "stackwise_kernel_sizes": [3, 3, 3, 3, 3, 3],
            "stackwise_num_repeats": [1, 2, 2, 3, 5, 8],
            "stackwise_input_filters": [32, 16, 32, 48, 96, 112],
            "stackwise_output_filters": [16, 32, 48, 96, 112, 192],
            "stackwise_expansion_ratios": [1, 4, 4, 4, 6, 6],
            "stackwise_squeeze_and_excite_ratios": [0, 0, 0, 0.25, 0.25, 0.25],
            "stackwise_strides": [1, 2, 2, 2, 1, 2],
            "stackwise_conv_types": [
                "fused",
                "fused",
                "fused",
                "unfused",
                "unfused",
                "unfused",
            ],
        },
        "weights_url": "https://storage.googleapis.com/keras-cv/models/efficientnetv2b0/imagenet/classification-v0-notop.h5",  # noqa: E501
        "weights_hash": "ac95f13a8ad1cee41184fc16fd0eb769f7c5b3131151c6abf7fcee5cc3d09bc8",  # noqa: E501
    },
    "efficientnetv2_b1_imagenet": {
        "metadata": {
            "description": (
                "EfficientNet B-style architecture with 6 "
                "convolutional blocks. This B-style model has "
                "`width_coefficient=1.0` and `depth_coefficient=1.1`. "
                "Weights are "
                "initialized to pretrained imagenet classification weights."
                "Published weights are capable of scoring 79.1%	top 1 accuracy "
                "and 94.4% top 5 accuracy on imagenet."
            ),
            "params": 6931124,
            "official_name": "EfficientNetV2",
            "path": "efficientnetv2",
        },
        "class_name": "keras_cv>EfficientNetV2Backbone",
        "config": {
            "width_coefficient": 1.0,
            "depth_coefficient": 1.1,
            "skip_connection_dropout": 0.2,
            "depth_divisor": 8,
            "min_depth": 8,
            "activation": "swish",
            "include_rescaling": True,
            "input_shape": (None, None, 3),
            "input_tensor": None,
            "stackwise_kernel_sizes": [3, 3, 3, 3, 3, 3],
            "stackwise_num_repeats": [1, 2, 2, 3, 5, 8],
            "stackwise_input_filters": [32, 16, 32, 48, 96, 112],
            "stackwise_output_filters": [16, 32, 48, 96, 112, 192],
            "stackwise_expansion_ratios": [1, 4, 4, 4, 6, 6],
            "stackwise_squeeze_and_excite_ratios": [0, 0, 0, 0.25, 0.25, 0.25],
            "stackwise_strides": [1, 2, 2, 2, 1, 2],
            "stackwise_conv_types": [
                "fused",
                "fused",
                "fused",
                "unfused",
                "unfused",
                "unfused",
            ],
        },
        "weights_url": "https://storage.googleapis.com/keras-cv/models/efficientnetv2b1/imagenet/classification-v0-notop.h5",  # noqa: E501
        "weights_hash": "82da111f8411f47e3f5eef090da76340f38e222f90a08bead53662f2ebafb01c",  # noqa: E501
    },
    "efficientnetv2_b2_imagenet": {
        "metadata": {
            "description": (
                "EfficientNet B-style architecture with 6 "
                "convolutional blocks. This B-style model has "
                "`width_coefficient=1.1` and `depth_coefficient=1.2`. "
                "Weights are initialized to pretrained "
                "imagenet classification weights."
                "Published weights are capable of scoring 80.1%	top 1 accuracy "
                "and 94.9% top 5 accuracy on imagenet."
            ),
            "params": 8769374,
            "official_name": "EfficientNetV2",
            "path": "efficientnetv2",
        },
        "class_name": "keras_cv>EfficientNetV2Backbone",
        "config": {
            "width_coefficient": 1.1,
            "depth_coefficient": 1.2,
            "skip_connection_dropout": 0.2,
            "depth_divisor": 8,
            "min_depth": 8,
            "activation": "swish",
            "include_rescaling": True,
            "input_shape": (None, None, 3),
            "input_tensor": None,
            "stackwise_kernel_sizes": [3, 3, 3, 3, 3, 3],
            "stackwise_num_repeats": [1, 2, 2, 3, 5, 8],
            "stackwise_input_filters": [32, 16, 32, 48, 96, 112],
            "stackwise_output_filters": [16, 32, 48, 96, 112, 192],
            "stackwise_expansion_ratios": [1, 4, 4, 4, 6, 6],
            "stackwise_squeeze_and_excite_ratios": [0, 0, 0, 0.25, 0.25, 0.25],
            "stackwise_strides": [1, 2, 2, 2, 1, 2],
            "stackwise_conv_types": [
                "fused",
                "fused",
                "fused",
                "unfused",
                "unfused",
                "unfused",
            ],
        },
        "weights_url": "https://storage.googleapis.com/keras-cv/models/efficientnetv2b2/imagenet/classification-v0-notop.h5",  # noqa: E501
        "weights_hash": "02d12c9d1589b540b4e84ffdb54ff30c96099bd59e311a85ddc7180efc65e955",  # noqa: E501
    },
}

backbone_presets = {
    **backbone_presets_no_weights,
    **backbone_presets_with_weights,
}




# Copyright 2023 The KerasCV Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""RetinaNet Task presets."""
from keras_cv.src.models.backbones.resnet_v1 import resnet_v1_backbone_presets

retinanet_presets = {
    "retinanet_resnet50_pascalvoc": {
        "metadata": {
            "description": (
                "RetinaNet with a ResNet50 v1 backbone. "
                "Trained on PascalVOC 2012 object detection task, which "
                "consists of 20 classes. This model achieves a final MaP of "
                "0.33 on the evaluation set."
            ),
            "params": 35596952,
            "official_name": "RetinaNet",
            "path": "retinanet",
        },
        "config": {
            "backbone": resnet_v1_backbone_presets.backbone_presets["resnet50"],
            # 21 used as an implicit background class marginally improves
            # performance.
            "num_classes": 20,
        },
        "weights_url": "https://storage.googleapis.com/keras-cv/models/retinanet/pascal_voc/resnet50-v4.h5",  # noqa: E501
        "weights_hash": "961f6f9a03c869900d61ae74a9f0c31c6439b4f81f13593f5c16c4733061fbac",  # noqa: E501
    },
}




# Copyright 2023 The KerasCV Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""SAM model preset configurations."""

from keras_cv.src.models.backbones.vit_det import vit_det_backbone_presets

prompt_encoder_preset = {
    "class_name": "keras_cv.models>SAMPromptEncoder",
    "config": {
        "embed_dim": 256,
        "image_embedding_size": (64, 64),
        "input_image_size": (1024, 1024),
        "mask_in_chans": 16,
        "activation": "gelu",
    },
}

mask_decoder_preset = {
    "class_name": "keras_cv.models>SAMMaskDecoder",
    "config": {
        "transformer_dim": 256,
        "transformer": {
            "class_name": "keras_cv.models>TwoWayTransformer",
            "config": {
                "depth": 2,
                "embed_dim": 256,
                "num_heads": 8,
                "mlp_dim": 2048,
                "activation": "relu",
                "attention_downsample_rate": 2,
            },
        },
        "num_multimask_outputs": 3,
        "iou_head_depth": 3,
        "iou_head_hidden_dim": 256,
        "activation": "gelu",
    },
}

sam_presets = {
    "sam_base_sa1b": {
        "metadata": {
            "description": "The base SAM model trained on the SA1B dataset.",
            "params": 93_735_728,
            "official_name": "SAM",
            "path": "segment_anything",
        },
        "config": {
            "backbone": vit_det_backbone_presets.backbone_presets[
                "vitdet_base"
            ],
            "prompt_encoder": prompt_encoder_preset,
            "mask_decoder": mask_decoder_preset,
        },
        "weights_url": "https://storage.googleapis.com/keras-cv/models/segment_anything/sam_base.h5",  # noqa: E501
        "weights_hash": "5a18868ed227b6f093d4a6cb7ed689868dd11f288a8311ae69002a9a9d86d192",  # noqa: E501
    },
    "sam_large_sa1b": {
        "metadata": {
            "description": "The large SAM model trained on the SA1B dataset.",
            "params": 312_343_088,
            "official_name": "SAM",
            "path": "segment_anything",
        },
        "config": {
            "backbone": vit_det_backbone_presets.backbone_presets[
                "vitdet_large"
            ],
            "prompt_encoder": prompt_encoder_preset,
            "mask_decoder": mask_decoder_preset,
        },
        "weights_url": "https://storage.googleapis.com/keras-cv/models/segment_anything/sam_large.h5",  # noqa: E501
        "weights_hash": "4ef43d3a8e24200c14a086a043dec8e956fef500c6171268a35029ea720305f0",  # noqa: E501
    },
    "sam_huge_sa1b": {
        "metadata": {
            "description": "The huge SAM model trained on the SA1B dataset.",
            "params": 641_090_864,
            "official_name": "SAM",
            "path": "segment_anything",
        },
        "config": {
            "backbone": vit_det_backbone_presets.backbone_presets[
                "vitdet_huge"
            ],
            "prompt_encoder": prompt_encoder_preset,
            "mask_decoder": mask_decoder_preset,
        },
        "weights_url": "https://storage.googleapis.com/keras-cv/models/segment_anything/sam_huge.h5",  # noqa: E501
        "weights_hash": "3284c7c3c91274e8cb1ec2de69da3b6d6cee4483f7d8b0e17e1042b9dfc86fe5",  # noqa: E501
    },
}




# Copyright 2023 The KerasCV Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""YOLOv8 Task presets."""
from keras_cv.src.models.object_detection.yolo_v8 import yolo_v8_backbone_presets

yolo_v8_detector_presets = {
    "yolo_v8_m_pascalvoc": {
        "metadata": {
            "description": (
                "YOLOV8-M pretrained on PascalVOC 2012 object detection task, "
                "which consists of 20 classes. This model achieves a final MaP "
                "of 0.45 on the evaluation set."
            ),
            "params": 25901004,
            "official_name": "YOLOV8Detector",
            "path": "yolo_v8_detector",
        },
        "config": {
            "backbone": yolo_v8_backbone_presets.backbone_presets[
                "yolo_v8_m_backbone"
            ],
            "num_classes": 20,
            "fpn_depth": 2,
        },
        "weights_url": "https://storage.googleapis.com/keras-cv/models/yolov8/pascal_voc/yolov8_m_v1.h5",  # noqa: E501
        "weights_hash": "2891fbd66f71e0b9da0cb02ef3afbccb819e1b8f18204157f643f4ec058a71a8",  # noqa: E501
    },
}

